@@ -34,7 +34,7 @@ gboolean            strchrs                      (const char *str,
 char *              str_substitute               (const char *str,
 						  const char *from_str,
 						  const char *to_str);
-int                 strcmp_null_tollerant        (const char *s1, const char *s2);
+int                 strcmp_null_tolerant        (const char *s1, const char *s2);
 char*               escape_str_common            (const char *str,
 						  const char *meta_chars,
 						  const char  prefix,
